@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 1999-2015 Horde LLC (http://www.horde.org/)
+ * Copyright 1999-2016 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * not receive such a file, see also http://www.horde.org/licenses/gpl.
@@ -112,10 +112,11 @@ $injector->getInstance('Horde_Core_Factory_Imple')->create('Kronolith_Ajax_Imple
 $injector->getInstance('Horde_Core_Factory_Imple')->create('Kronolith_Ajax_Imple_ContactAutoCompleter', array(
     'box' => 'kronolithAttendeesACBox',
     'id' => 'kronolithEventAttendees',
-    'onAdd' => 'function(attendee) { KronolithCore.addAttendee(attendee); KronolithCore.checkOrganizerAsAttendee(); }',
+    'onAdd' => 'function(a) { KronolithCore.addAttendee(a); KronolithCore.checkOrganizerAsAttendee(); }',
     'onRemove' => 'KronolithCore.removeAttendee.bind(KronolithCore)',
     'pretty' => true,
-    'triggerContainer' => 'kronolithAttendeesACTriggerContainer'
+    'triggerContainer' => 'kronolithAttendeesACTriggerContainer',
+    'beforeUpdate' => 'function(a) { return KronolithCore.normalizeAttendee(a); }'
 ));
 
 $injector->getInstance('Horde_Core_Factory_Imple')->create('Kronolith_Ajax_Imple_ResourceAutoCompleter', array(
