@@ -2,7 +2,7 @@
 /**
  * Kronolith wrapper for the base AJAX framework handler.
  *
- * Copyright 2012-2015 Horde LLC (http://www.horde.org/)
+ * Copyright 2012-2016 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
@@ -123,7 +123,8 @@ class Kronolith_Ajax
                 'delete' => Horde_Perms::DELETE,
                 'delegate' => Kronolith::PERMS_DELEGATE
             ),
-            'tasks' => $has_tasks ? $registry->tasks->ajaxDefaults() : null
+            'tasks' => $has_tasks ? $registry->tasks->ajaxDefaults() : null,
+            'confirm_delete' => $prefs->getValue('confirm_delete')
         ));
 
         /* Make sure this value is not optimized out by array_filter(). */
