@@ -2,7 +2,7 @@
 /**
  * Imple to attach the contact autocompleter to a HTML element.
  *
- * Copyright 2005-2015 Horde LLC (http://www.horde.org/)
+ * Copyright 2005-2016 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
@@ -20,7 +20,7 @@ class Kronolith_Ajax_Imple_ContactAutoCompleter extends Horde_Core_Ajax_Imple_Co
     {
         $opts = array();
 
-        foreach (array('box', 'onAdd', 'onRemove', 'triggerContainer') as $val) {
+        foreach (array('box', 'onAdd', 'onRemove', 'triggerContainer', 'beforeUpdate') as $val) {
             if (isset($this->_params[$val])) {
                 $opts[$val] = $this->_params[$val];
             }
