@@ -5,7 +5,7 @@
  * This file defines Horde's core API interface. Other core Horde libraries
  * can interact with Kronolith through this API.
  *
- * Copyright 2010-2015 Horde LLC (http://www.horde.org/)
+ * Copyright 2010-2016 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
@@ -47,7 +47,7 @@ class Kronolith_Application extends Horde_Registry_Application
 
     /**
      */
-    public $version = 'H5 (4.2.9)';
+    public $version = 'H5 (4.2.13)';
 
     /**
      * Global variables defined:
@@ -522,6 +522,10 @@ class Kronolith_Application extends Horde_Registry_Application
                             'user' => $alarm_user
                         ));
                     }
+                    // Don't show alarms for private events if not the owner.
+                    if ($event->isPrivate($alarm_user)) {
+                        continue;
+                    }
                     $shown_calendars = unserialize($prefs->getValue('display_cals'));
                     $reminder = $prefs->getValue('event_reminder');
                     if (($reminder == 'owner' && $alarm_user == $owner) ||
@@ -720,7 +724,7 @@ class Kronolith_Application extends Horde_Registry_Application
             ->getInstance('Horde_Dav_Storage');
 
         $internal = $dav->getInternalCollectionId($collection, 'calendar') ?: $collection;
-        if (!Kronolith::hasPermission($internal, Horde_Perms::READ)) {
+        if (!Kronolith::hasPermission($internal, Horde_Perms::SHOW)) {
             throw new Kronolith_Exception(_("Calendar does not exist or no permission to edit"));
         }
 
@@ -761,7 +765,7 @@ class Kronolith_Application extends Horde_Registry_Application
             ->getInstance('Horde_Dav_Storage');
 
         $internal = $dav->getInternalCollectionId($collection, 'calendar') ?: $collection;
-        if (!Kronolith::hasPermission($internal, Horde_Perms::READ)) {
+        if (!Kronolith::hasPermission($internal, Horde_Perms::SHOW)) {
             throw new Kronolith_Exception(_("Calendar does not exist or no permission to edit"));
         }
 
