@@ -3,7 +3,7 @@
  * Kronolith_Driver defines an API for implementing storage backends for
  * Kronolith.
  *
- * Copyright 1999-2015 Horde LLC (http://www.horde.org/)
+ * Copyright 1999-2016 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
@@ -443,6 +443,9 @@ class Kronolith_Driver
     /**
      * Stub to be overridden in the child class.
      *
+     * Note: This method only "Purges" the calendar - removing the
+     * events, it doesn't remove the calendar itself.
+     *
      * @throws Kronolith_Exception
      */
     public function delete($calendar)
@@ -498,6 +501,10 @@ class Kronolith_Driver
         $tagger = Kronolith::getTagger();
         $tagger->replaceTags($event->uid, array(), $event->creator, Kronolith_Tagger::TYPE_EVENT);
 
+        /* Tell content we removed the object */
+        $GLOBALS['injector']->getInstance('Content_Objects_Manager')
+            ->delete(array($event->uid), Kronolith_Tagger::TYPE_EVENT);
+
         /* Remove any geolocation data. */
         try {
             $GLOBALS['injector']->getInstance('Kronolith_Geo')->deleteLocation($event->id);
